Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(96)

Unified Diff: components/user_manager/user.h

Issue 1747843002: Rename raw_image() to image_bytes() in UserImage (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/user_manager/user.h
diff --git a/components/user_manager/user.h b/components/user_manager/user.h
index 0d6431b6ebc670748a811d379398eb204f425490..54d7573ce90831e468517a64fa98c8fa0d1133fb 100644
--- a/components/user_manager/user.h
+++ b/components/user_manager/user.h
@@ -127,13 +127,13 @@ class USER_MANAGER_EXPORT User : public UserInfo {
bool HasDefaultImage() const;
int image_index() const { return image_index_; }
- bool has_raw_image() const { return user_image_.has_raw_image(); }
- // Returns raw representation of static user image.
- const UserImage::RawImage& raw_image() const {
- return user_image_.raw_image();
+ bool has_web_image() const { return user_image_.has_web_image(); }
+ // Returns web representation of static user image.
+ const UserImage::WebImage& web_image() const {
+ return user_image_.web_image();
}
// Whether |raw_image| contains data in format that is considered safe to
hashimoto 2016/02/29 08:01:59 Shouldn't |web_image| be replaced with |user_image
satorux1 2016/02/29 08:11:41 Done.
// decode in sensitive environment (on Login screen).
@@ -127,13 +127,13 @@ class USER_MANAGER_EXPORT User : public UserInfo {
}
- // Whether |raw_image| contains data in format that is considered safe to
+ // Whether |web_image| contains data in format that is considered safe to
hashimoto 2016/02/29 08:01:59 Shouldn't |web_image| be replaced with |user_image
satorux1 2016/02/29 08:11:41 Done.
bool image_is_safe_format() const { return user_image_.is_safe_format(); }

Powered by Google App Engine
This is Rietveld 408576698